@@ -92,44 +92,6 @@ skip_if_mocked("can't check country when mocking is in place", 1, sub {
 $number = Number::Phone->new('+447693912345');
 ok($number->is_pager(), "pagers correctly identified");
 
-# see https://github.com/DrHyde/perl-modules-Number-Phone/issues/112
-# checked on 2023-12-10
-# next check due 2024-06-01 (semi-annually)
-subtest "0800 716 range has the wrong length, OFCOM says 10 digits but 0800 716 598 is diallable" => sub {
-    $number = Number::Phone->new('+44800716598'); # used by Barclays
-    isa_ok(
-        $number,
-        (is_mocked_uk()
-            ? 'Number::Phone::StubCountry::MOCK'
-            : 'Number::Phone::UK'
-        )
-    );
-    ok($number->is_tollfree(), "valid 9 digit number in a range supposedly for 10 digit numbers");
-
-    $number = Number::Phone->new(
-        (is_mocked_uk() ? 'MOCK' : 'UK'),
-        '0800716598'
-    );
-    isa_ok(
-        $number,
-        (is_mocked_uk()
-            ? 'Number::Phone::StubCountry::MOCK'
-            : 'Number::Phone::UK'
-        )
-    );
-    ok($number->is_tollfree(), "valid 9 digit number (national format) in a range supposedly for 10 digit numbers");
-
-    # this is invalid, it's a digit appended to the above, but this may
-    # be a mixed 9 and 10 digit range, so test it to make sure the length
-    # check passes
-    $number = Number::Phone->new('+448007165980');
-    ok($number->is_tollfree(), "10 digit number also in that range");
-
-    # this is invalid, it's too short, in that mixed range
-    $number = Number::Phone->new('+4480071659');
-    is($number, undef, "too short number doesn't validate");
-};
-
 $number = Number::Phone->new('+44800001012');
 ok($number->is_tollfree(), "toll-free numbers with significant F digit correctly identified");
 # 0500 is Quarantined
@@ -147,11 +109,12 @@ skip_if_mocked("libphonenumber doesn't know about location/operators/network-ser
   $number = Number::Phone->new('+449090901234');
   ok($number->is_adult() && $number->is_specialrate(), "0909 'adult' numbers correctly identified");
 
-  $number = Number::Phone->new('+445588301234');
+  $number = Number::Phone->new('+445555881234');
   ok($number->is_corporate(), "corporate numbers correctly identified");
+  is($number->operator(), "Network Rail Infrastructure Limited", "operators correctly identified");
 
   $number = Number::Phone->new('+448450033845');
-  is($number->operator(), 'Gci Network Solutions Limited', "operators correctly identified");
+  is($number->operator(), 'GCI Network Solutions Limited', "operators for 08 correctly identified");
 
   $number = Number::Phone->new('+442087712924');
   subtest "geo numbers have correct location" => sub {
@@ -187,7 +150,7 @@ ok($number, "0870 'Allocated for Migration only' fixed");
 $number = Number::Phone->new('+447092306588'); # dodgy spaces were appearing in data
 ok($number, "bad 070 data fixed");
 
-$number = Number::Phone->new('+442030791234'); # new London 020 3 numbers
+$number = Number::Phone->new('+442030781234'); # new London 020 3 numbers
 ok($number, "0203 numbers are recognised");
 
 # libphonenumber doesn't do allocation but does think geographic numbers are fixed lines
